@@ -10,13 +10,18 @@ class Swift_Transport_StreamBuffer_TlsSocketAcceptanceTest extends Swift_Transpo
         if (!\in_array('tls', $streams)) {
             $this->markTestSkipped(
                 'TLS is not configured for your system.  It is not possible to run this test'
-             );
+            );
         }
         if (!\defined('SWIFT_TLS_HOST')) {
             $this->markTestSkipped(
                 'Cannot run test without a TLS enabled SMTP host to connect to (define '.
                 'SWIFT_TLS_HOST in tests/acceptance.conf.php if you wish to run this test)'
-             );
+            );
+        }
+        if (\PHP_VERSION_ID < 70200) {
+            $this->markTestSkipped(
+                'Tests fail on PHP 7.1 and below.'
+            );
         }
         parent::setUp();
     }
